<?php
/*
Plugin Name: Virtual Robots.txt
Plugin URI: https://www.littlebizzy.com/plugins/virtual-robotstxt
Description: Replaces the default virtual robots.txt generated by WordPress with an editable one, and deletes any physical robots.txt file that may already exist.
Version: 1.0.6
Author: LittleBizzy
Author URI: https://www.littlebizzy.com
License: GPLv3
License URI: http://www.gnu.org/licenses/gpl-3.0.html
Prefix: VRTRBT
*/

// Admin Notices module
require_once dirname(__FILE__).'/admin-notices.php';
VRTRBT_Admin_Notices::instance(__FILE__);


/* Initialization */

// Block direct calls
if (!function_exists('add_action'))
	die;

// Plugin constants
define('VRTRBT_FILE', __FILE__);
define('VRTRBT_PATH', dirname(VRTRBT_FILE));
define('VRTRBT_VERSION', '1.0.6');


/* Robots page hook */

// WP parse query hook
add_action('parse_query', 'vrtrbt_parse_query', 0);

// WP parse query handler
function vrtrbt_parse_query($wp_query) {
	if ($wp_query->is_main_query() && $wp_query->is_robots) {
		require_once(VRTRBT_PATH.'/core/robots.php');
		VRTRBT_Core_Robots::output();
	}
}


/* Admin area */

// Only admin from here
if (!is_admin())
	return;

// Admin menu hook
add_action('admin_menu', 'vrtrbt_admin_menu');

// Create item in options menu
function vrtrbt_admin_menu() {
	add_submenu_page('options-general.php', 'Robots.txt', 'Robots.txt', 'manage_options', 'robotstxt', 'vrtrbt_admin_page');
}

// Admin page form
function vrtrbt_admin_page() {
	require_once(VRTRBT_PATH.'/admin/admin.php');
	VRTRBT_Admin::form();
}


/* Activation hooks */

// Plugin activation
register_activation_hook(VRTRBT_FILE, 'vrtrbt_activation');
function vrtrbt_activation() {
	require_once(VRTRBT_PATH.'/core/robots.php');
	VRTRBT_Core_Robots::activation();
}

// Plugin uninstall
register_uninstall_hook(VRTRBT_FILE, 'vrtrbt_uninstall');
function vrtrbt_uninstall() {
	require_once(VRTRBT_PATH.'/core/robots.php');
	VRTRBT_Core_Robots::uninstall();
}
